# python-selvpcclient

[![Build Status](https://travis-ci.org/selectel/python-selvpcclient.svg?branch=master)](https://travis-ci.org/selectel/python-selvpcclient)

This is a client for the Selectel VPC API. There is a Python API
(the selvpcclient module), and command-line script (installed as **selvpc**).

## Overview

- [Selectel VPC REST API documentation](https://developers.selectel.ru/docs/selectel-cloud-platform/main-services/selectel_cloud_management_api/)
- [PyPi](https://pypi.org/project/python-selvpcclient)
- [GitHub](https://github.com/selectel/python-selvpcclient)
- [Bugs](https://github.com/selectel/python-selvpcclient/issues) - issue tracking
- (ru) [Library overview](https://selectel.ru/blog/python-selvpcclient/)

## Installing from PyPI

        pip install -U python-selvpcclient

License
-------

Apache 2.0
